@@ -1,5 +1,7 @@
 """
-Main interface for cloudwatch service literal definitions.
+Type annotations for cloudwatch service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/literals.html)
 
 Usage::
 
